Class: DummySmsMobilePhoneValidator

Inherits:
Decidim::Initiatives::ValidateMobilePhone
  • Object
show all
Defined in:
lib/decidim/generators/app_templates/dummy_sms_mobile_phone_validator.rb

Overview

This class overrides the two methods of the parent class ensuring that the user has a previous sms authorization with the same phone number provided in the initiative signature workflow. In this way only the sms code received in the phone is verified and no previous authorization is necessary.

Instance Method Summary collapse

Instance Method Details

#authorized?Boolean

Returns:

  • (Boolean)


8
# File 'lib/decidim/generators/app_templates/dummy_sms_mobile_phone_validator.rb', line 8

def authorized? = true

#phone_match?Boolean

Returns:

  • (Boolean)


10
# File 'lib/decidim/generators/app_templates/dummy_sms_mobile_phone_validator.rb', line 10

def phone_match? = true