Class: EphemeralDummyAuthorizationHandler
- Inherits:
-
DummyAuthorizationHandler
- Object
- Decidim::AuthorizationHandler
- DummyAuthorizationHandler
- EphemeralDummyAuthorizationHandler
- Defined in:
- lib/decidim/generators/app_templates/ephemeral_dummy_authorization_handler.rb
Instance Method Summary collapse
-
#to_partial_path ⇒ Object
This method is set to use the same partial as DummyAuthorizationHandler instead of inferring it from the class name.
Methods inherited from DummyAuthorizationHandler
Instance Method Details
#to_partial_path ⇒ Object
This method is set to use the same partial as DummyAuthorizationHandler instead of inferring it from the class name
6 7 8 |
# File 'lib/decidim/generators/app_templates/ephemeral_dummy_authorization_handler.rb', line 6 def to_partial_path "dummy_authorization/form" end |